@@ -1,5 +1,6 @@
 from __future__ import absolute_import, unicode_literals
 
+import importlib
 import inspect
 import logging
 import os
@@ -15,6 +16,14 @@ from six.moves import builtins
 
 from .utils import WhateverIO, decorator, get_logger_handlers, noop
 
+try:
+    from importlib import reload
+except ImportError:
+    try:
+        from imp import reload
+    except ImportError:
+        reload = reload
+
 try:
     from unittest import mock
 except ImportError:
@@ -550,6 +559,8 @@ def reset_modules(*modules):
     prev = dict((k, sys.modules.pop(k))
                 for k in modules if k in sys.modules)
     try:
+        for k in modules:
+            reload(importlib.import_module(k))
         yield
     finally:
         sys.modules.update(prev)
